"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _button = _interopRequireDefault(require("../button/button"));

var _field = _interopRequireDefault(require("./field"));

var _form = _interopRequireDefault(require("./form"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/* eslint-disable react/jsx-props-no-spreading */
var setupExample = function setupExample(props) {
  return _react["default"].createElement(_form["default"], props, _react["default"].createElement(_field["default"], {
    id: "firstName",
    name: "firstName"
  }), _react["default"].createElement(_field["default"], {
    id: "lastName",
    name: "lastName"
  }), _react["default"].createElement(_field["default"], {
    id: "email",
    name: "email",
    type: "email"
  }), _react["default"].createElement("footer", null, _react["default"].createElement(_button["default"], {
    caption: "Send",
    display: "primary",
    type: "submit"
  }), _react["default"].createElement(_button["default"], {
    caption: "Clear",
    type: "reset"
  })));
};

describe('form', function () {
  it('wraps children with a form element', function () {
    var wrapper = (0, _enzyme.shallow)(setupExample());
    expect(wrapper.find('form')).toHaveLength(1);
    expect(wrapper.find(_field["default"])).toHaveLength(3);
    expect(wrapper.find(_button["default"])).toHaveLength(2);
  });
  it.skip('form footer', function () {
    var wrapper = (0, _enzyme.shallow)(setupExample());
    expect(wrapper.find('footer')).not.toExist();
    expect(wrapper.find('.form-footer')).toHaveLength(1);
    expect(wrapper.find(_button["default"])).toHaveLength(2);
    expect(wrapper.find('.form-footer').find(_button["default"])).toHaveLength(2);
    expect(wrapper.find('.form-footer').find(_field["default"])).not.toExist();
  });
  it('submit event', function () {
    var callback = jest.fn();
    var wrapper = (0, _enzyme.mount)(setupExample({
      onSubmit: callback
    }));
    wrapper.find('form').first().simulate('submit');
    expect(callback).toHaveBeenCalledWith({});
    wrapper.unmount();
  });
  it('submit event handler receives object with fields', function () {
    var firstName = 'Fernando';
    var lastName = 'Pasik';
    var email = 'fernando@pasik.com.ar';
    var callback = jest.fn();
    var wrapper = (0, _enzyme.mount)(setupExample({
      onSubmit: callback
    }));
    wrapper.find('input[name="firstName"]').simulate('change', {
      target: {
        value: firstName
      }
    });
    wrapper.find('input[name="lastName"]').simulate('change', {
      target: {
        value: lastName
      }
    });
    wrapper.find('input[name="email"]').simulate('change', {
      target: {
        value: email
      }
    });
    wrapper.find('form').simulate('submit');
    expect(callback).toHaveBeenCalledWith({
      firstName: firstName,
      lastName: lastName,
      email: email
    });
    wrapper.unmount();
  });
  it.skip('clears the state on reset event', function () {
    var firstName = 'Fernando';
    var lastName = 'Pasik';
    var email = 'fernando@pasik.com.ar';
    var callback = jest.fn();
    var wrapper = (0, _enzyme.mount)(setupExample({
      onReset: callback
    }));
    wrapper.find('input[name="firstName"]').simulate('change', {
      target: {
        value: firstName
      }
    });
    wrapper.find('input[name="lastName"]').simulate('change', {
      target: {
        value: lastName
      }
    });
    wrapper.find('input[name="email"]').simulate('change', {
      target: {
        value: email
      }
    });
    wrapper.find('form').simulate('reset');
    expect(callback).toHaveBeenCalledWith({});
    wrapper.unmount();
  });
});